@@ -120,7 +120,7 @@ Vector12d EulerOdeSolver::f(const double& x, const Vector12d& y) const
    (void)x;
 
    // vec omega in body coor. sys.: omega_body = (p, q, r)
-   const Vector3d omega_body(y.start<3>());
+   const Vector3d omega_body(y.head<3>());
 
    // body unit vectors in fixed frame coordinates
    Matrix3d e;
@@ -354,7 +354,7 @@ void RotationGLWidget::paintGL(void)
    glPushMatrix();
    // calculate the transform which rotates the unit z vector onto omega
    glLoadMatrixd(
-      Transform<double,3>(
+      Projective3d(
          Quaternion<double>()
          .setFromTwoVectors(Vector3d::UnitZ(), m_saver.omega())
          .toRotationMatrix())
@@ -371,7 +371,7 @@ void RotationGLWidget::paintGL(void)
    // create transformation/rotation matrix from the body and its unit axes
    glPushMatrix();
    glLoadMatrixd(
-      Transform<double,3>(m_saver.e().front())
+      Projective3d(m_saver.e().front())
       .data());
 
    // draw the body unit axis
@@ -556,7 +556,7 @@ void KRotationSaver::initData()
 
    // assemble initial y for solver
    Vector12d y;
-   y.start<3>() = omega_body;
+   y.head<3>() = omega_body;
    // 3 basis vectors of body system in fixed coordinates
    y.segment<3>(3) = et.col(0);
    y.segment<3>(6) = et.col(1);
@@ -667,7 +667,7 @@ void KRotationSaver::doTimeStep()
    }
 
    // current rotation vector omega
-   m_omega = m_e.front() * y.start<3>();
+   m_omega = m_e.front() * y.head<3>();
 
    // set new random traces every 10 seconds
    if (m_randomTraces)
